@@ -4,6 +4,9 @@ import typing
 from pathlib import Path
 from datetime import datetime
 
+from bigflow import commons
+from bigflow.workflow import DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS
+
 
 def clear_dags_output_dir(workdir: str):
     dags_dir_path = get_dags_output_dir(workdir)
@@ -43,7 +46,7 @@ default_args = {{
             'start_date': {start_date_as_str},
             'email_on_failure': False,
             'email_on_retry': False,
-            'execution_timeout': datetime.timedelta(minutes=180),
+            'execution_timeout': datetime.timedelta(seconds={execution_timeout_sec}),
 }}
 
 dag = DAG(
@@ -55,7 +58,8 @@ dag = DAG(
 """.format(dag_id=dag_deployment_id,
            start_date_as_str=start_date_as_str,
            schedule_interval=workflow.schedule_interval,
-           depends_on_past=workflow.depends_on_past))
+           depends_on_past=workflow.depends_on_past,
+           execution_timeout_sec=DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS))
 
     def get_job(workflow_job):
         return workflow_job.job
@@ -65,6 +69,10 @@ dag = DAG(
         job_var = "t" + str(job.id)
         task_id = job.id.replace("_","-")
 
+        execution_timeout_sec = commons.as_timedelta(
+            getattr(job, 'execution_timeout_sec', None)
+            or DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS)
+
         dag_chunks.append("""
 {job_var} = kubernetes_pod_operator.KubernetesPodOperator(
     task_id='{task_id}',
@@ -76,14 +84,17 @@ dag = DAG(
     is_delete_operator_pod=True,
     retries={retries},
     retry_delay=datetime.timedelta(seconds={retry_delay}),
-    dag=dag)
+    dag=dag,
+    execution_timeout={execution_timeout_sec!r})
 """.format(job_var=job_var,
           task_id=task_id,
           docker_image = docker_repository+":"+build_ver,
           bf_job= workflow.workflow_id+"."+job.id,
           root_folder=root_package_name,
           retries=job.retry_count if hasattr(job, 'retry_count') else 3,
-          retry_delay=job.retry_pause_sec if hasattr(job, 'retry_pause_sec') else 60))
+          retry_delay=job.retry_pause_sec if hasattr(job, 'retry_pause_sec') else 60,
+          execution_timeout_sec=execution_timeout_sec,
+          ))
 
         for d in dependencies:
             up_job_var = "t" + str(get_job(d).id)
