@@ -7,6 +7,8 @@ import datetime as dt
 import bigflow
 
 import logging
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -17,6 +19,9 @@ _RUNTIME_FORMATS = [
     "%Y-%m-%d",
 ]
 
+DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS = 10800  # 3 hours
+DEFAULT_PIPELINE_LEVEL_EXECUTION_TIMEOUT_SHIFT_IN_SECONDS = 120  # 2 minutes
+
 
 def get_timezone_offset_seconds() -> int:
     return dt.datetime.now().astimezone().tzinfo.utcoffset(None).seconds
@@ -102,8 +107,9 @@ class Job(abc.ABC):
     """Base abstract class for bigflow.Jobs.  It is recommended to inherit all your jobs from this class."""
 
     id: str
-    retries: int = 3
-    retry_delay: float = 60
+    retry_count: int = 3
+    retry_pause_sec: int = 60
+    execution_timeout_sec: int = DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS
 
     @abc.abstractmethod
     def execute(self, context: JobContext):
@@ -190,14 +196,14 @@ class WorkflowJob(Job):
     def id(self):
         return self.job.id
 
-    @property
-    def retries(self):
-        return self.job.retries
-
     @property
     def retry_count(self):
         return self.job.retry_count
 
+    @property
+    def retry_pause_sec(self):
+        return self.job.retry_pause_sec
+
     def execute(self, context: JobContext):
         Workflow._execute_job(self.job, context)
 
@@ -344,4 +350,4 @@ def _parse_runtime_str(runtime: str):
             return dt.datetime.strptime(runtime, format)
         except ValueError:
             pass
-    raise ValueError("Unable to parse 'runtime' %r" % rt)
+    raise ValueError("Unable to parse 'runtime' %r" % runtime)
