@@ -1,4 +1,5 @@
-from unittest import TestCase, mock
+from unittest import TestCase
+from unittest import mock
 from unittest.mock import patch
 
 import apache_beam as beam
@@ -10,59 +11,60 @@ from collections import defaultdict
 from bigflow import JobContext, Workflow
 
 from bigflow.dataflow import BeamJob
-from bigflow.commons import DEFAULT_JOB_EXECUTION_TIMEOUT
+from bigflow.workflow import DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS, DEFAULT_PIPELINE_LEVEL_EXECUTION_TIMEOUT_SHIFT_IN_SECONDS
 
 
 class CountWordsFn(beam.DoFn):
-    def __init__(self, save):
+    def __init__(self, CounterState):
         super().__init__()
-        self.save = save
+        self.CounterState = CounterState
 
     def process(self, element, *args, **kwargs):
         word, count = element
-        self.save.counter[word] += len(count)
+        self.CounterState.counter[word] += len(count)
         yield word, len(count)
 
 
-class Save(object):
+class CounterState(object):
     counter = defaultdict(int)
 
 
-class Saver(beam.PTransform):
-    def __init__(self, save):
+class CounterStater(beam.PTransform):
+    def __init__(self, CounterState):
         super().__init__()
-        self.save = save
+        self.CounterState = CounterState
 
     def expand(self, records_to_delete):
         return records_to_delete \
-               | "SaveCountedWords" >> beam.ParDo(
-            CountWordsFn(self.save))
+               | "CounterStateCountedWords" >> beam.ParDo(
+            CountWordsFn(self.CounterState))
 
 
 class CountWordsDriver:
-    def __init__(self, saver):
+    def __init__(self, CounterStater):
         self.result = None
         self.context = None
         self.pipeline = None
-        self.saver = saver
+        self.CounterStater = CounterStater
 
     def run(self, pipeline: Pipeline, context: JobContext, driver_arguments: dict):
         words_input = pipeline | 'LoadingWordsInput' >> beam.Create(driver_arguments['words_to_count'])
-        words_input | 'FilterWords' >> beam.Filter(lambda w: w in driver_arguments['words_to_filter']) \
-        | 'MapToCount' >> beam.Map(lambda w: (w, 1))\
-        | 'GroupWords' >> beam.GroupByKey()\
-        | 'CountWords' >> self.saver
+        words_input | 'FilterWords' >> (beam.Filter(lambda w: w in driver_arguments['words_to_filter'])
+                                        | 'MapToCount' >> beam.Map(lambda w: (w, 1))
+                                        | 'GroupWords' >> beam.GroupByKey()
+                                        | 'CountWords' >> self.CounterStater)
         self.context = context
         self.pipeline = pipeline
 
 
+@mock.patch('sys.argv', ["python"])  # Beam tries to parse cmdargs eagerly - it breaks external test launchers
 class BeamJobTestCase(TestCase):
 
     @patch.object(RunnerResult, 'is_in_terminal_state', create=True)
     def test_should_run_beam_job(self, is_in_terminal_state_mock):
         # given
         is_in_terminal_state_mock.return_value = True
-        driver = CountWordsDriver(Saver(Save()))
+        driver = CountWordsDriver(CounterStater(CounterState()))
         job = BeamJob(
             id='count_words',
             entry_point=driver.run,
@@ -80,7 +82,7 @@ class BeamJobTestCase(TestCase):
         count_words.run('2020-01-01')
 
         # then executes the job with the arguments
-        self.assertEqual(driver.saver.save.counter, {'valid': 2, 'word': 1})
+        self.assertEqual(driver.CounterStater.CounterState.counter, {'valid': 2, 'word': 1})
 
         # and passes the context
         self.assertIsNotNone(driver.context)
@@ -91,18 +93,18 @@ class BeamJobTestCase(TestCase):
             driver.pipeline._options.get_all_options()['labels'],
             ['workflow_id=count_words'])
 
-        # and sets default value for job_execution_timeout and execution_timeout
-        self.assertEqual(job.job_execution_timeout, DEFAULT_JOB_EXECUTION_TIMEOUT)
-        self.assertEqual(job.execution_timeout, DEFAULT_JOB_EXECUTION_TIMEOUT - 120000)
+        # and sets default value for execution_timeout_sec
+        self.assertEqual(job.execution_timeout_sec, DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS)
 
     @patch.object(RunnerResult, 'is_in_terminal_state', create=True)
     @patch.object(RunnerResult, 'cancel')
     @patch.object(RunnerResult, 'wait_until_finish')
-    def test_should_run_beam_job_with_timeout_with_cancel(self, wait_until_finish_mock, cancel_mock, is_in_terminal_state_mock):
+    def test_should_run_beam_job_with_timeout_with_cancel(self, wait_until_finish_mock, cancel_mock,
+                                                          is_in_terminal_state_mock):
         # given
         wait_until_finish_mock.return_value = 'DONE'
         is_in_terminal_state_mock.return_value = False
-        driver = CountWordsDriver(Saver(Save()))
+        driver = CountWordsDriver(CounterStater(CounterState()))
         job = BeamJob(
             id='count_words',
             entry_point=driver.run,
@@ -111,7 +113,7 @@ class BeamJobTestCase(TestCase):
                 'words_to_count': ['trash', 'valid', 'word', 'valid']
             },
             test_pipeline=self._test_pipeline_with_label('count_words'),
-            execution_timeout=3)
+            execution_timeout_sec=600)
 
         count_words = Workflow(
             workflow_id='count_words',
@@ -122,16 +124,17 @@ class BeamJobTestCase(TestCase):
 
         # then
         self.assertEqual(cancel_mock.call_count, 1)
-        wait_until_finish_mock.assert_called_with(3)
+        wait_until_finish_mock.assert_called_with((600 - DEFAULT_PIPELINE_LEVEL_EXECUTION_TIMEOUT_SHIFT_IN_SECONDS) * 1000)
 
     @patch.object(RunnerResult, 'is_in_terminal_state', create=True)
     @patch.object(RunnerResult, 'cancel')
     @patch.object(RunnerResult, 'wait_until_finish')
-    def test_should_run_beam_job_with_timeout_without_cancel(self, wait_until_finish_mock, cancel_mock, is_in_terminal_state_mock):
+    def test_should_run_beam_job_with_timeout_without_cancel(self, wait_until_finish_mock, cancel_mock,
+                                                             is_in_terminal_state_mock):
         # given
         wait_until_finish_mock.return_value = 'DONE'
         is_in_terminal_state_mock.return_value = True
-        driver = CountWordsDriver(Saver(Save()))
+        driver = CountWordsDriver(CounterStater(CounterState()))
         job = BeamJob(
             id='count_words',
             entry_point=driver.run,
@@ -139,7 +142,8 @@ class BeamJobTestCase(TestCase):
                 'words_to_filter': ['valid', 'word'],
                 'words_to_count': ['trash', 'valid', 'word', 'valid']
             },
-            test_pipeline=self._test_pipeline_with_label('count_words'))
+            test_pipeline=self._test_pipeline_with_label('count_words'),
+            execution_timeout_sec=600)
 
         count_words = Workflow(
             workflow_id='count_words',
@@ -150,40 +154,29 @@ class BeamJobTestCase(TestCase):
 
         # then
         self.assertEqual(cancel_mock.call_count, 0)
-        wait_until_finish_mock.assert_called_with(DEFAULT_JOB_EXECUTION_TIMEOUT - 120000)
+        wait_until_finish_mock.assert_called_with((600 - DEFAULT_PIPELINE_LEVEL_EXECUTION_TIMEOUT_SHIFT_IN_SECONDS) * 1000)
 
-    @patch.object(RunnerResult, 'is_in_terminal_state', create=True)
-    @patch.object(RunnerResult, 'cancel')
-    def test_should_run_beam_job_without_timeout_if_wait_until_finish_disabled(self, cancel_mock, is_in_terminal_state_mock):
-        is_in_terminal_state_mock.return_value = False
+    def test_should_throw_if_wait_until_finish_set_to_false_and_execution_timeout_passed(self):
         # given
-        driver = CountWordsDriver(Saver(Save()))
-        job = BeamJob(
-            id='count_words',
-            entry_point=driver.run,
-            entry_point_arguments={
-                'words_to_filter': ['valid', 'word'],
-                'words_to_count': ['trash', 'valid', 'word', 'valid']
-            },
-            test_pipeline=self._test_pipeline_with_label('count_words'),
-            execution_timeout=1)
-
-        count_words = Workflow(
-            workflow_id='count_words',
-            definition=[job])
-
-        # when
-        count_words.run('2020-01-01')
-
-        # then executes the job with the arguments
-        self.assertEqual(cancel_mock.call_count, 1)
+        with self.assertRaises(ValueError):
+            driver = CountWordsDriver(CounterStater(CounterState()))
+            job = BeamJob(
+                id='count_words',
+                entry_point=driver.run,
+                entry_point_arguments={
+                    'words_to_filter': ['valid', 'word'],
+                    'words_to_count': ['trash', 'valid', 'word', 'valid']
+                },
+                test_pipeline=self._test_pipeline_with_label('count_words'),
+                execution_timeout_sec=1,
+                wait_until_finish=False)
 
     @patch.object(RunnerResult, 'is_in_terminal_state', create=True)
     @patch.object(BeamJob, '_create_pipeline')
     def test_should_create_pipeline_from_pipeline_options(self, _create_pipeline_mock, is_in_terminal_state_mock):
         # given
         is_in_terminal_state_mock.return_value = True
-        driver = CountWordsDriver(Saver(Save()))
+        driver = CountWordsDriver(CounterStater(CounterState()))
         options = PipelineOptions()
         job = BeamJob(
             id='count_words',
@@ -193,7 +186,7 @@ class BeamJobTestCase(TestCase):
                 'words_to_count': ['trash', 'valid', 'word', 'valid']
             },
             pipeline_options=options,
-            execution_timeout=1)
+            execution_timeout_sec=1)
 
         count_words = Workflow(
             workflow_id='count_words',
@@ -207,7 +200,7 @@ class BeamJobTestCase(TestCase):
 
     def test_should_throw_if_pipeline_options_and_pipeline_both_not_provided(self):
         with self.assertRaises(ValueError):
-            driver = CountWordsDriver(Saver(Save()))
+            driver = CountWordsDriver(CounterStater(CounterState()))
             BeamJob(
                 id='count_words',
                 entry_point=driver.run,
@@ -215,11 +208,11 @@ class BeamJobTestCase(TestCase):
                     'words_to_filter': ['valid', 'word'],
                     'words_to_count': ['trash', 'valid', 'word', 'valid']
                 },
-                execution_timeout=1)
+                execution_timeout_sec=1)
 
     def test_should_throw_if_pipeline_options_and_pipeline_both_provided(self):
         with self.assertRaises(ValueError):
-            driver = CountWordsDriver(Saver(Save()))
+            driver = CountWordsDriver(CounterStater(CounterState()))
             BeamJob(
                 id='count_words',
                 entry_point=driver.run,
@@ -228,7 +221,7 @@ class BeamJobTestCase(TestCase):
                     'words_to_count': ['trash', 'valid', 'word', 'valid']
                 },
                 test_pipeline=self._test_pipeline_with_label('count_words'),
-                execution_timeout=1,
+                execution_timeout_sec=1,
                 pipeline_options=PipelineOptions())
 
     def _test_pipeline_with_label(self, workflow_id):
@@ -236,4 +229,4 @@ class BeamJobTestCase(TestCase):
         google_cloud_options = pipeline_options.view_as(GoogleCloudOptions)
         google_cloud_options.labels = []
         google_cloud_options.labels.append(f'workflow_id={workflow_id}')
-        return TestPipeline(options=google_cloud_options)
\ No newline at end of file
+        return TestPipeline(options=google_cloud_options)
