@@ -10,10 +10,10 @@ import google.cloud.dataproc_v1
 import google.cloud.storage
 
 import bigflow
-from bigflow import dataproc
 import bigflow.dataproc
 import bigflow.resources
-from bigflow.commons import DEFAULT_JOB_EXECUTION_TIMEOUT
+
+from bigflow.workflow import DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS
 
 _someobject_tags = set()
 
@@ -40,12 +40,6 @@ class _SomeObject:
 
 class PySparkJobTest(unittest.TestCase):
 
-    def tearDown(self):
-        try:
-            (pathlib.Path(__file__).parent / "example_project/setup.py").unlink()
-        except FileNotFoundError:
-            pass
-
     def test_generates_driver_for_callable(self):
 
         for callable, expected_tag in [
@@ -93,26 +87,6 @@ class PySparkJobTest(unittest.TestCase):
             content_type='application/octet-stream',
         )
 
-    def test_build_python_egg_file_for_project(self):
-
-        # given
-        setup_py = pathlib.Path(__file__).parent / "example_project/setup.py"
-        bigflow.resources.find_or_create_setup_for_main_project_package(
-            'main_package',
-            pathlib.Path(__file__).parent / "example_project/main_project/job",
-        )
-
-        # when
-        egg = bigflow.dataproc._build_project_egg(setup_py)
-
-        # then
-        egg_path = pathlib.Path(egg)
-        self.assertTrue(egg_path.exists())
-
-        # cleanup
-        egg_path.unlink()
-        setup_py.unlink()
-
     def test_should_create_new_cluster_for_job(self):
 
         # given
@@ -150,22 +124,6 @@ class PySparkJobTest(unittest.TestCase):
             cluster_data['config']['gce_cluster_config']['metadata'],
         )
 
-    def test_should_detect_project_root(self):
-
-        # given
-        from test.example_project.main_package.job import create_pyspark_job
-        pyspark_job = create_pyspark_job()
-
-        # when
-        self.assertIsNone(pyspark_job.setup_file)
-        pyspark_job._ensure_has_setup_file()
-
-        # then
-        self.assertEqual(
-            pyspark_job.setup_file,
-            pathlib.Path(__file__).parent / "example_project/setup.py",
-        )
-
     def test_should_send_correct_job_request_to_dataproc(self):
 
         # given
@@ -220,12 +178,9 @@ class PySparkJobTest(unittest.TestCase):
         from test.example_project.main_package.job import create_pyspark_job
         pyspark_job = create_pyspark_job()
 
-        storage = storage_client_cls.return_value
         cluster_controller = cluster_controller_client_cls.return_value
         job_controller = job_controller_client_cls.return_value
 
-        bucket = storage.get_bucket.return_value
-
         submit_job_result = mock.Mock()
         submit_job_result.reference.job_id = "the-job"
         job_controller.submit_job = mock.Mock(return_value=submit_job_result)
@@ -335,6 +290,7 @@ class PySparkJobTest(unittest.TestCase):
             bucket_id="no-bucket",
             gcp_project_id="no-project",
             gcp_region="no-region",
+            project_name="test",
         )
 
         # when
@@ -344,7 +300,7 @@ class PySparkJobTest(unittest.TestCase):
         self.assertIn('spark.executorEnv.bf_log_config', props)
         self.assertIn('spark.executorEnv.bf_workflow_id', props)
 
-    def test_should_initialize_job_with_default_job_execution_timeout(self):
+    def test_should_initialize_job_with_default_execution_timeout(self):
         # when
         job = bigflow.dataproc.PySparkJob(
             "some_job",
@@ -355,4 +311,18 @@ class PySparkJobTest(unittest.TestCase):
         )
 
         # then
-        self.assertEqual(job.job_execution_timeout, DEFAULT_JOB_EXECUTION_TIMEOUT)
+        self.assertEqual(job.execution_timeout_sec, DEFAULT_EXECUTION_TIMEOUT_IN_SECONDS)
+
+    def test_should_initialize_job_with_execution_timeout(self):
+        # when
+        job = bigflow.dataproc.PySparkJob(
+            "some_job",
+            id,
+            bucket_id="no-bucket",
+            gcp_project_id="no-project",
+            gcp_region="no-region",
+            execution_timeout_sec=1,
+        )
+
+        # then
+        self.assertEqual(job.execution_timeout_sec, 1)
